import scipy.io as io
import numpy as np
import chronoptics.tof as tof

# Input file name
inFile = "frames.csf"

# Output file name
outFile = "frames.mat"

reader = tof.CsfReader(inFile)

matDict = {}
try:
    while True:
        # Read frame
        frame = reader.readFrame()

        # Prepare dict item
        matItem = {
            "nrows": frame.rows(),
            "ncols": frame.cols(),
            "frame_type": frame.frameType(),
            "frame_id": frame.frameId(),
            "frame_count": frame.frameCount(),
            "frame": np.asarray(frame),
            "scale": frame.scale(),
            "addition": frame.addition(),
        }

        # Add to dict
        name = "frame_{}".format(frame.frameCount())
        matDict[name] = matItem
except Exception:
    print("End reached")

# Save dict as matlab mat file
io.savemat(outFile, matDict, do_compression=True)
